# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.list_tools_response import ListToolsResponse
from ...types.multi_server_tools_response import MultiServerToolsResponse

McpServerGetToolsResponse = typing.Union[ListToolsResponse, MultiServerToolsResponse]
